Skip to content

Extracts scenario names from coupled runs in the given outputfolder. The scenario names will be extracted based on the folder names of the results folders.

Usage

findCoupledruns(resultsfolder)

Arguments

resultsfolder

Path to an output folder.

Value

A vector containing the names of the scenarios.

Author

David Klein