Skip to content

Print each git author's first name, last name, and mail address in a way that could be copy pasted into DESCRIPTION. Please note that this list usually still needs to be carefully checked e.g. for duplicates and cleaned.

Usage

gitAuthors()

Value

Invisibly, a data.frame with the following columns: raw, firstName, lastName, mailAdress.

Author

Pascal Sauer