Skip to content

Support function which validates a key out of a version date combination

Usage

validkey(package = ".", stopIfInvalid = FALSE)

Arguments

package

Path to the package

stopIfInvalid

logical; whether to stop if the key is invalid.

Value

list with version, date and result of validation test

Details

This function is used to check whether buildLibrary has been run properly and without problems or not

See also

Author

Jan Philipp Dietrich