Checks if the version number in the DESCRIPTION file of a given package has been updated (may not be a version number for development stage packages).
Usage
isVersionUpdated(
repo = "https://rse.pik-potsdam.de/r/packages/",
config = loadBuildLibraryConfig()
)