Produces the reporting mif files where they are missing
Source:R/produce_missing_reports.R
produce_missing_reports.RdFor coupled runs: Searches the output folder for all existing run folders, checks which of them are currently running on the cluster, ignores them, checks for the remaining runs whether there is a reporting. Produces the reporting if it is missing. #'