Reads all runtime information from given experiments. The runtime is given in hours and is the runtime of GAMS.
Arguments
- path
Path to a run or a vector of paths.
- plot
Logical indicating whether the output should be plotted to a pdf with the name runtime.pdf.
- types
A vector of names of different types of runs which should be distinguished by colors. The names have to be part of the folder name in order to allow the function to map the given types to the runs.
- coupled
Logical indicating if comparison plots should be added for coupled REMIND and MAgPIE runs.
TRUEautomatically setstypestoc("-rem-","-mag-")and overwrites user definedtypes- outfname
Optional name of the pdf. If nothing is given the default "runtime" will be used.