Renames the scenariofolder and the scenario contained in it
Source:R/rename_scenario.R
rename_scenario.RdUse this function to change the name of a run after it has finished. This function renames the run folder, change the run title in the cfg and in the reporting. This can be useful if the initial name of a run was not meaningful. However, inconsistencies will remain, since the function will NOT rename the scenario in the list file, the gdx, and the results database.