R/snakeToCamel.R
snakeToCamel.Rd
Convenience function to rename variables in an R file from snake to camel case.
snakeToCamel(pathToFile, ask = TRUE)
Path to the R source file where variables should be renamed.
If TRUE (default) ask before renaming a variable, otherwise always assume "yes" as answer.