Installs a package in a temporary library and loads that library on top of the existing one
Usage
testPackage(repo, tmpLib = tempdir(), ...)Arguments
- repo
GitHub repository to install the package from
- tmpLib
temporary library directory where the package should be installed
- ...
additional arguments forwarded to
devtools::install_github