Support function which validates a key out of a version date combination
Details
This function is used to check whether buildLibrary has been run
properly and without problems or not
Support function which validates a key out of a version date combination
This function is used to check whether buildLibrary has been run
properly and without problems or not